#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_REC_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_REC_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/rec.hpp>

#endif
